@@ -13,7 +13,6 @@ from ..drawables.linegl import LineGL
 from ..drawables.pointgl import PointGL
 from ..drawables.tubegl import TubeGL
 from ..drawables.textgl import TextGL
-from ..drawables.gridgl import GridGL
 
 from ..glprograms.meshprogram import MeshProgram
 from ..glprograms.wireprogram import WireProgram
@@ -32,7 +31,6 @@ from ..glprograms.xsectionmeshprogram import XSectionMeshProgram
 from ..glprograms.xsectionblockprogram import XSectionBlockProgram
 
 from ..glprograms.textprogram import TextProgram
-from ..glprograms.gridprogram import GridProgram
 
 
 class GLDrawableCollection(GLCollection):
@@ -59,6 +57,3 @@ class GLDrawableCollection(GLCollection):
 
         # Text
         self.associate(TextProgram(), TextGL)
-
-        # Axis
-        self.associate(GridProgram(), GridGL)
