@@ -161,7 +161,7 @@ class TextGL(GLDrawable):
 
         # Offset
         for i in range(len(self.text_vertices)):
-            self.text_vertices[i] = (self.text_vertices[i].reshape((-1, 3)) + self.rendering_offset).astype(np.float32)
+            self.text_vertices[i] = self.text_vertices[i].reshape((-1, 3)).astype(np.float32)
 
     def generate_buffers(self) -> None:
         self._vaos = [glGenVertexArrays(1)]
