@@ -103,15 +103,11 @@ class IntegrableViewer(QOpenGLWidget):
         self.current_controller = None
         self.controllers = {}
 
-        # Model/View/Projection matrices (math)
+        # Model/View/Projection matrices
         self.model_matrix = QMatrix4x4()
         self.view_matrix = QMatrix4x4()
         self.proj_matrix = QMatrix4x4()
 
-        # Model/View matrices (rendering offset)
-        self.render_model_matrix = QMatrix4x4()
-        self.render_view_matrix = QMatrix4x4()
-
         # FPS Counter
         self.fps_counter = FPSCounter()
 
@@ -138,9 +134,10 @@ class IntegrableViewer(QOpenGLWidget):
         self.initialize()
 
     def initialize(self) -> None:
-        # Orientation-Axis/Background
-        self.register_drawable(self.factory.axis(), self.post_collection)
-        self.register_drawable(self.factory.background(), self.pre_collection)
+        # Axis/Background/Grid
+        self.register_drawable(self.factory.background(id=0), self.pre_collection)
+        self.register_drawable(self.factory.axis(id=1), self.post_collection)
+        self.register_drawable(self.factory.grid(id=2, visible=False), self.post_collection)
 
         # Signals
         self.signal_file_modified.connect(self.recreate)
@@ -179,23 +176,22 @@ class IntegrableViewer(QOpenGLWidget):
         # Clear screen
         glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
 
-        # Setup model matrix
-        self.setup_model_matrix(self.model_matrix, self.rotation_angle, self.rotation_center)
-        self.setup_model_matrix(self.render_model_matrix, self.rotation_angle, self.render_rotation_center)
-
-        # Setup view matrix
-        self.setup_view_matrix(self.view_matrix, self.camera_position)
-        self.setup_view_matrix(self.render_view_matrix, self.render_camera_position)
+        # Setup matrices
+        self.setup_model_matrix(self.model_matrix, self.rotation_angle, self.render_rotation_center)
+        self.setup_view_matrix(self.view_matrix, self.render_camera_position)
 
         # Propagate common uniform values (programs lacking the uniform will ignore the command)
         for collection in [self.pre_collection, self.drawable_collection, self.post_collection]:
             # MVP matrices
             collection.update_uniform('proj_matrix', self.proj_matrix)
-            collection.update_uniform('model_view_matrix', self.render_view_matrix * self.render_model_matrix)
+            collection.update_uniform('model_view_matrix', self.view_matrix * self.model_matrix)
 
             # Viewport values (with DPI awareness)
             collection.update_uniform('viewport', *self.viewport)
 
+            # Rendering offset (avoid wobbling when rotating the camera)
+            collection.update_uniform('rendering_offset', *self.rendering_offset)
+
             # Update common uniforms (programs lacking the uniform will ignore the command)
             collection.update_uniform('plane_origin', *self.last_cross_origin)
             collection.update_uniform('plane_normal', *self.last_cross_normal)
@@ -238,6 +234,21 @@ class IntegrableViewer(QOpenGLWidget):
         matrix.setToIdentity()
         matrix.translate(*-camera)
 
+    """
+    Environment drawables
+    """
+    @property
+    def background(self) -> GLDrawable:
+        return self.pre_collection.get(0)
+
+    @property
+    def axis(self) -> GLDrawable:
+        return self.post_collection.get(1)
+
+    @property
+    def grid(self) -> GLDrawable:
+        return self.post_collection.get(2)
+
     """
     Properties
     """
@@ -249,14 +260,6 @@ class IntegrableViewer(QOpenGLWidget):
     def last_drawable(self) -> GLDrawable:
         return self.get_drawable(self.last_id)
 
-    @property
-    def axis(self) -> GLDrawable:
-        return self.post_collection.get_last()
-
-    @property
-    def background(self) -> GLDrawable:
-        return self.pre_collection.get_last()
-
     @property
     def off_center(self) -> np.ndarray:
         return self.camera_position - self.rotation_center
@@ -311,12 +314,6 @@ class IntegrableViewer(QOpenGLWidget):
     def rendering_offset(self, value: iter) -> None:
         self._rendering_offset = np.asarray(value)
 
-        for drawable in self.get_all_drawables():
-            drawable.rendering_offset = value
-
-        if self.is_gl_initialized:
-            self.update_all()
-
     @property
     def render_camera_position(self) -> np.ndarray:
         return self.camera_position + self.rendering_offset
@@ -448,9 +445,6 @@ class IntegrableViewer(QOpenGLWidget):
         drawable.add_observer(self)
         collection.add(drawable)
 
-        # Update the new drawable with the current rendering offset
-        drawable.rendering_offset = self.rendering_offset
-
         # Emit success signals
         self.signal_file_modified.emit()
         self.signal_load_success.emit(drawable.id)
@@ -478,9 +472,6 @@ class IntegrableViewer(QOpenGLWidget):
     def text(self, *args, **kwargs) -> TextGL:
         return self.register_drawable(self.factory.text(*args, **kwargs))
 
-    def grid(self, *args, **kwargs) -> GridGL:
-        return self.register_drawable(self.factory.grid(*args, **kwargs))
-
     """
     Load methods by path
     """
